@@ -1,9 +1,9 @@
 <?php
 
 // Bench script of Cache_Lite
-// $Id: bench.php,v 1.6 2002/09/28 18:05:29 fab Exp $
+// $Id$
 
-require_once('Cache/Lite.php');
+require_once __DIR__ . '/../Cache/Lite.php';
 
 $options = array(
     'caching' => true,
@@ -24,4 +24,4 @@ if ($data = $Cache_Lite->get('123')) {
     $Cache_Lite->save($data);
 }
 
-?>
\ No newline at end of file
+?>
